@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::SupportBundleGenerator;
@@ -22,27 +22,24 @@ our @ObjectDependencies = (
     'Kernel::System::Package',
     'Kernel::System::Registration',
     'Kernel::System::SupportDataCollector',
-    'Kernel::System::Time',
+    'Kernel::System::SysConfig',
+    'Kernel::System::DateTime',
 );
 
 =head1 NAME
 
 Kernel::System::SupportBundleGenerator - support bundle generator
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 All support bundle generator functions.
 
 =head1 PUBLIC INTERFACE
 
-=over 4
+=head2 new()
 
-=item new()
+Don't use the constructor directly, use the ObjectManager instead:
 
-create an object. Do not use it directly, instead use:
-
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $SupportBundleGeneratorObject = $Kernel::OM->Get('Kernel::System::SupportBundleGenerator');
 
 =cut
@@ -66,7 +63,7 @@ sub new {
     return $Self;
 }
 
-=item Generate()
+=head2 Generate()
 
 Generates a support bundle C<.tar> or C<.tar.gz> with the following contents: Registration Information,
 Support Data, Installed Packages, and another C<.tar> or C<.tar.gz> with all changed or new files in the
@@ -161,6 +158,21 @@ sub Generate {
         };
     }
 
+    # get the configuration dump
+    ( $SupportFiles{ConfigurationDumpContent}, $SupportFiles{ConfigurationDumpFilename} )
+        = $Self->GenerateConfigurationDump();
+    if ( !$SupportFiles{ConfigurationDumpFilename} ) {
+        my $Message = 'Can not get the configuration dump!';
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => $Message,
+        );
+        return {
+            Success => 0,
+            Message => $Message,
+        };
+    }
+
     # get config object
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
@@ -187,7 +199,7 @@ sub Generate {
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
 
     my @List;
-    for my $Key (qw(PackageList RegistrationInfo SupportData CustomFilesArchive)) {
+    for my $Key (qw(PackageList RegistrationInfo SupportData CustomFilesArchive ConfigurationDump)) {
 
         if ( $SupportFiles{ $Key . 'Filename' } && $SupportFiles{ $Key . 'Content' } ) {
 
@@ -206,15 +218,8 @@ sub Generate {
         }
     }
 
-    # get time object
-    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
-
-    ## no critic
-    my ( $s, $m, $h, $D, $M, $Y, $wd, $yd, $dst ) = $TimeObject->SystemTime2Date(
-        SystemTime => $TimeObject->SystemTime(),
-    );
-    ## use critic
-    my $Filename = "SupportBundle_$Y-$M-$D" . '_' . "$h-$m";
+    my $DateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
+    my $Filename = "SupportBundle_" . $DateTimeObject->Format( Format => "%Y-%m-%d_%H-%M" );
 
     # add files to the tar archive
     my $Archive   = $TempDir . '/' . $Filename;
@@ -272,7 +277,7 @@ sub Generate {
     };
 }
 
-=item GenerateCustomFilesArchive()
+=head2 GenerateCustomFilesArchive()
 
 Generates a C<.tar> or C<.tar.gz> file with all eligible changed or added files taking the ARCHIVE file as a reference
 
@@ -329,29 +334,29 @@ sub GenerateCustomFilesArchive {
     my $HomeWithoutSlash = $Self->{Home};
     $HomeWithoutSlash =~ s{\A\/}{};
 
-    # Mask Passwords in Config.pm
-    my $Config = $TarObject->get_content( $HomeWithoutSlash . '/Kernel/Config.pm' );
+    # Mask passwords in Config files.
+    CONFIGFILE:
+    for my $ConfigFile ( $TarObject->list_files() ) {
 
-    if ( !$Config ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "Kernel/Config.pm was not found in the modified files!",
+        next CONFIGFILE if ( $ConfigFile !~ 'Kernel/Config.pm' && $ConfigFile !~ 'Kernel/Config/Files' );
+
+        my $Content = $TarObject->get_content($ConfigFile);
+
+        if ( !$Content ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "$ConfigFile was not found in the modified files!",
+            );
+            next CONFIGFILE;
+        }
+
+        $Content = $Self->_MaskPasswords(
+            StringToMask => $Content,
         );
-        return;
+
+        $TarObject->replace_content( $ConfigFile, $Content );
     }
 
-    # Trim any passswords from Config.pm.
-    # Simple settings like $Self->{'DatabasePw'} or $Self->{'AuthModule::LDAP::SearchUserPw1'}
-    $Config =~ s/(\$Self->\{'[^']+(?:Password|Pw)\d*'\}\s*=\s*)\'.*?\'/$1\'xxx\'/mg;
-
-    # Complex settings like:
-    #     $Self->{CustomerUser1} = {
-    #         Params => {
-    #             UserPw => 'xxx',
-    $Config =~ s/((?:Password|Pw)\d*\s*=>\s*)\'.*?\'/$1\'xxx\'/mg;
-
-    $TarObject->replace_content( $HomeWithoutSlash . '/Kernel/Config.pm', $Config );
-
     my $Write = $TarObject->write( $CustomFilesArchive, 0 );
     if ( !$Write ) {
 
@@ -400,7 +405,7 @@ sub GenerateCustomFilesArchive {
     return ( \$TmpTar, 'application.tar' );
 }
 
-=item GeneratePackageList()
+=head2 GeneratePackageList()
 
 Generates a .csv file with all installed packages
 
@@ -441,7 +446,7 @@ sub GeneratePackageList {
     return ( \$CSVContent, 'InstalledPackages.csv' );
 }
 
-=item GenerateRegistrationInfo()
+=head2 GenerateRegistrationInfo()
 
 Generates a C<.json> file with the otrs system registration information
 
@@ -491,7 +496,34 @@ sub GenerateRegistrationInfo {
     return ( \$JSONContent, 'RegistrationInfo.json' );
 }
 
-=item GenerateSupportData()
+=head2 GenerateConfigurationDump()
+
+Generates a <.yml> file with the otrs system registration information
+
+    my ( $Content, $Filename ) = $SupportBundleGeneratorObject->GenerateConfigurationDump();
+
+Returns:
+    $Content  = $FileContentsRef;
+    $Filename = <'ModifiedSettings.yml'>;
+
+=cut
+
+sub GenerateConfigurationDump {
+    my ( $Self, %Param ) = @_;
+
+    my $Export = $Kernel::OM->Get('Kernel::System::SysConfig')->ConfigurationDump(
+        SkipDefaultSettings => 1,
+    );
+
+    $Export = $Self->_MaskPasswords(
+        StringToMask => $Export,
+        YAML         => 1
+    );
+
+    return ( \$Export, 'ModifiedSettings.yml' );
+}
+
+=head2 GenerateSupportData()
 
 Generates a C<.json> file with the support data
 
@@ -554,7 +586,7 @@ sub _GetMD5SumLookup {
         %PackageMD5SumLookup = ( %PackageMD5SumLookup, %{$PartialMD5Sum} );
     }
 
-    # add MD5Sums from all packages to the list from framwork ARCHIVE
+    # add MD5Sums from all packages to the list from framework ARCHIVE
     # overwritten files by packages will also overwrite the MD5 Sum
     %MD5SumLookup = ( %MD5SumLookup, %PackageMD5SumLookup );
 
@@ -579,7 +611,7 @@ sub _GetCustomFileList {
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
     # article directory
-    my $ArticleDir = $ConfigObject->Get('ArticleDir');
+    my $ArticleDir = $ConfigObject->Get('Ticket::Article::Backend::MIMEBase::ArticleDataDir');
 
     # cleanup file name
     $ArticleDir =~ s/\/\//\//g;
@@ -655,15 +687,43 @@ sub _GetCustomFileList {
     return @Files;
 }
 
-=back
+sub _MaskPasswords {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    for my $Needed (qw(StringToMask)) {
+        if ( !$Param{$Needed} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
+            return;
+        }
+    }
+
+    my $StringToMask = $Param{StringToMask};
+
+    # Trim any passswords.
+    # Simple settings like $Self->{'DatabasePw'} or $Self->{'AuthModule::LDAP::SearchUserPw1'}.
+    $StringToMask =~ s/(\$Self->\{'*[^']+(?:Password|Pw)\d*'*\}\s*=\s*)\'.*?\'/$1\'xxx\'/mg;
+
+    # Complex settings like:
+    #     $Self->{CustomerUser1} = {
+    #         Params => {
+    #             UserPw => 'xxx',
+    $StringToMask =~ s/((?:Password|Pw)\d*\s*=>\s*)\'.*?\'/$1\'xxx\'/mg;
+
+    return $StringToMask;
+
+}
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
 
