@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+// Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (GPL). If you
@@ -141,16 +141,6 @@ var Core = Core || {};
         });
 
         Core.UI.Table.InitTableFilter($("#FilterUsers"), $("#Users"));
-
-        // Define endsWith() method if a browser has no support for it, e.g. IE11 (see bug#14845).
-        if (typeof String.prototype.endsWith === 'undefined') {
-            String.prototype.endsWith = function(search, this_len) {
-                if (this_len === undefined || this_len > this.length) {
-                    this_len = this.length;
-                }
-                return this.substring(this_len - search.length, this_len) === search;
-            };
-        }
     };
 
 
@@ -478,20 +468,15 @@ var Core = Core || {};
             URL,
             Value,
             function(Response) {
-                var LinkURL = 'Action=AdminSystemConfigurationDeployment;Subaction=Deployment';
 
                 TargetNS.CleanWidgetClasses($Widget);
                 TargetNS.SettingRender(Response, $Widget);
 
                 if (Response.Data.SettingData.IsDirty) {
-                    if (Core.Config.Get('SessionUseCookie') === '0') {
-                        LinkURL += ';' + Core.Config.Get('SessionName') + '=' + Core.Config.Get('SessionID');
-                    }
-
                     Core.UI.ShowNotification(
                         Core.Language.Translate('You have undeployed settings, would you like to deploy them?'),
                         'Notice',
-                        LinkURL,
+                        'Action=AdminSystemConfigurationDeployment;Subaction=Deployment',
                         function() {
                             Core.UI.InitStickyElement();
                         }
@@ -1069,7 +1054,6 @@ var Core = Core || {};
             Core.Config.Get('Baselink'),
             Data,
             function(Response) {
-                var LinkURL = 'Action=AdminSystemConfigurationDeployment;Subaction=Deployment';
 
                 TargetNS.SettingRender(Response, $Widget);
                 TargetNS.CleanWidgetClasses($Widget);
@@ -1093,13 +1077,10 @@ var Core = Core || {};
                         );
                     }
                     else {
-                        if (Core.Config.Get('SessionUseCookie') === '0') {
-                            LinkURL += ';' + Core.Config.Get('SessionName') + '=' + Core.Config.Get('SessionID');
-                        }
                         Core.UI.ShowNotification(
                             Core.Language.Translate('You have undeployed settings, would you like to deploy them?'),
                             'Notice',
-                            LinkURL,
+                            'Action=AdminSystemConfigurationDeployment;Subaction=Deployment',
                             function() {
                                 Core.UI.InitStickyElement();
                             }
@@ -1663,7 +1644,6 @@ var Core = Core || {};
             Core.Config.Get('CGIHandle'),
             Data,
             function (HTML) {
-                var Counter = 0;
 
                 $(".ContentColumn").html(HTML);
                 TargetNS.Init();
@@ -1693,19 +1673,7 @@ var Core = Core || {};
                 // scroll to top to see all the settings from the current node
                 $('html, body').animate({
                     scrollTop: $('.ContentColumn .WidgetSimple').first().position().top
-                }, {
-                    duration: 'fast',
-                    always: function () {
-
-                        // This function is called 2 times: one time for html and another for body.
-                        // We want to set the class on element only when both are done.
-                        if (Counter === 1) {
-                            $('ul.SettingsList').addClass('Initialized');
-                        }
-
-                        Counter++;
-                    },
-                });
+                }, 'fast');
             }, 'html'
         );
 
